@@ -1,17 +1,17 @@
-# $Id: test.pl,v 1.2 2001/04/02 01:12:52 karl Exp $
+# $Id: test.pl,v 1.3 2004/04/22 15:41:21 cvonroes Exp $
 use HTTP::QuickBase;
 
 my $qdb = HTTP::QuickBase->new();
 $username="depositor";
 $password="Password";
 
-$res = $qdb->authenticate("$username","$password");
+$qdb->authenticate("$username","$password");
 
-$dbName="QuickBase API FAQ";
+$dbName="QuickBase KnowledgeBase and Support Center";
 
 $dbid = $qdb->getIDbyName($dbName);
 
-if ($dbid eq "6mztyxu8")
+if ($dbid eq "9kaw8phg")
    {
    print "Congratulations QuickBase.pm has been successfully installed!\n";
    exit(0);
